/* ******************************************************* plugin_info.h *** *
 * ץ饰 إåե
 *
 * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
 * Okayama University
 *                                  Time-stamp: <2001-11-20 23:20:25 sugaya>
 * ************************************************************************* */
#ifndef	__PLUGIN_INFO_H__
#define	__PLUGIN_INFO_H__

#include "gtkiconitemfactory.h"

typedef struct _PluginInfo {
  GtkIconItemFactoryEntry	menu_item;             /* ˥塼Ѥι¤ */
  gchar				*name;                               /* ̾ */
  gchar				*author;                           /*  */
  gchar				*version;                      /* С */
  gchar				*help;                               /*  */
  gint				active;
  void				(*plugin_func) (GdkPixbuf *,         /* ؿ */
						GdkPixbuf *);
} PluginInfo;   

#endif	/* __PLUGIN_INFO_H__ */

/* ************************************************ End of plugin_info.h *** */
